==> elixir-react-native-components-1.2.0.tgz: package/components/tdl/tdlFooter.js <==
import React, { useState } from "react";
import PropTypes from "prop-types";
import { HStack, Icon, InputRightAddon, InputLeftAddon, theme } from "native-base";
import { Modal, Platform, ScrollView, StyleSheet, Text, View } from "react-native";
import { Button } from "@ant-design/react-native";
import { getTheme } from "../../styles/themes";
import store from '../../redux';
import { Ionicons } from '@expo/vector-icons';
import { Feather } from '@expo/vector-icons';
import { MaterialIcons } from '@expo/vector-icons';


import {
    requestBack,
    sendSearchRequest,
    changeActiveTab,
    sendRefreshRequest,
    setIsDrawerOpen,
} from "../../redux/actions";
import Group from "../group/index";
import * as Util from "../../helpers/util";
import { getTranslation } from "../../labels";
import HTMLValue from "../htmlValue";
import { ArrowLeftOutlined, ArrowRightOutlined, InfoCircleOutlined, LeftOutlined, MoreOutlined, ReloadOutlined, RightOutlined, SearchOutlined } from "@ant-design/icons";
const themeTdl = getTheme("default");
const styles = StyleSheet.create({
    container: {
        alignItems: themeTdl.tdlContainer.alignItems,
        backgroundColor: themeTdl.tdlContainer.backgroundColor,
        padding: themeTdl.tdlContainer.padding,
    },
    modal: {
        flex: themeTdl.tdlModal.flex,
        alignItems: themeTdl.tdlModal.alignItems,
        backgroundColor: themeTdl.tdlModal.backgroundColor,
        padding: themeTdl.tdlModal.padding,
    },
    text: {
        color: themeTdl.tdlText.color,
        marginTop: themeTdl.tdlText.marginTop,
    },
});

const extractPropsFromVs = ({ vs, favorite }, changeTabHandler = () => { }) => {
    const {
        usecaseId,
        callerUsecaseId,
        count,
        filterInfo,
        filterName,
        hasServerFilter,
        isLoading,
        maxPageNumber,
        maxRowsSize,
        rowsNumber,
        favoriteItemInfo,
        callersLabelsArray,
    } = vs;
    const { SGroups, sortKeys, filtersNames, type, pageHelpSummary, pageHelp } = vs.tdl;
    const sortKey = vs.getSortKey();
    const actions = vs.getHeaderActions();
    const breads = [];
    return {
        usecaseId,
        callerUsecaseId,
        count,
        filterInfo,
        filterName,
        filtersNames,
        hasServerFilter,
        isLoading,
        maxPageNumber,
        maxRowsSize,
        rowsNumber,
        SGroups,
        sortKeys,
        type,
        sortKey,
        actions,
        breads,
        firstLevelEntry: callersLabelsArray.length === 0,
        inFavorite: favorite.find((item) => item.newTdlId === vs.tdl.tdlId),
        favoriteItemInfo,
        pageHelpSummary,
        pageHelp,
    };
};

const createSearchCriteriaModal = (vs, dispatch, timeZoneOffset, smallView, setSearchModalVisible, theme, isRTL) => {

    return (
        vs.tdl.SGroups &&
        vs.tdl.SGroups.map((sGroup, index) => (
            <>
                <ScrollView
                    style={{
                        flexGrow: theme.tdlScrollView.flexGrow,
                        // backgroundColor:"pink"
                    }}
                >
                    <Group
                        key={`${sGroup.id}${sGroup.pk}`}
                        vs={vs}
                        isSearch
                        tdlPath={`SGroups.${index}`}
                        dispatch={dispatch}
                        getTranslation={getTranslation}
                        smallView={smallView}
                        isRTL={isRTL}
                        theme={theme}
                    />
                </ScrollView>
                <View>
                    <Button
                        style={{ width: "100%" }}
                        onPress={() => {
                            dispatch(sendSearchRequest(vs.usecaseId));
                            setSearchModalVisible(false);
                        }}
                    >
                        <Text>{getTranslation("search")}</Text>
                    </Button>
                </View>
            </>
        ))
    );
};

const TdlFooter = ({ vs, favorite, dispatch, timeZoneOffset,
    smallView, isRTL, themeName, clientActions, showHeader }) => {
    const {
        usecaseId,
        callerUsecaseId,
        count,
        filterInfo,
        filterName,
        filtersNames,
        hasServerFilter,
        isLoading,
        maxPageNumber,
        maxRowsSize,
        rowsNumber,
        SGroups,
        sortKeys,
        type,
        sortKey,
        actions,
        breads,
        inFavorite,
        favoriteItemInfo,
        pageHelpSummary,
        pageHelp,
        firstLevelEntry,
    } = extractPropsFromVs({ vs, favorite }, (targetUsecaseId) => {
        if (targetUsecaseId === "home") {
            dispatch(changeActiveTab("home"));
            return;
        }
        if (targetUsecaseId !== vs.usecaseId) {
            dispatch(requestBack(vs.usecaseId, targetUsecaseId));
        }
    });


    // console.log("isRTL in TDLHeader");
    // console.log(isRTL);
    const [helpModalVisible, setHelpModalVisible] = useState(false);
    const [searchModalVisible, setSearchModalVisible] = useState(false);
    const theme = getTheme(themeName);


    const backButton = (
        <Button
            transparent
            style={{ ...theme.headerIcon }}
            onPress={() => {
                // console.log("theme.headerIcon");
                //console.log(theme.headerIcon);
                setSearchModalVisible(false);
            }}
        >

            <Icon

                as={Ionicons}
                name={isRTL ? "arrow-back" : "arrow-forward"}
                style={{
                    ...theme.headerIcon,
                    padding: theme.tdlIcon.padding,
                    margin: theme.tdlIcon.margin,

                }}
            />
        </Button>
    );
    const optionsButton = (
        <Button
            transparent
            style={theme.headerIcon}
            onPress={() => {
                console.log("more clicked");
                dispatch(setIsDrawerOpen(true));
            }}
        >
            {Platform.OS != "web" &&
                <Feather name="more-vertical" size={25} style={{ ...theme.headerIcon }} />
            }
            {Platform.OS == "web" &&
                <MoreOutlined style={{ ...theme.headerIcon }} />
            }
        </Button>
    );

    const headerButtons = (
        <>
            {pageHelp != null && pageHelp !== "" && (
                <Button
                    transparent
                    style={theme.headerIcon}
                    onPress={() => {
                        setHelpModalVisible(true);
                    }}
                >
                    {Platform.OS != "web" &&
                        <Icon as={MaterialIcons} name="info" style={{ ...theme.headerIcon }} />
                    }
                    {Platform.OS == "web" &&
                        <InfoCircleOutlined style={{ ...theme.headerIcon }} />
                    }
                </Button>
            )}

            {vs.tdl.type === "SMS" && (
                <Button
                    transparent
                    style={theme.headerIcon}
                    onPress={() => {
                        setSearchModalVisible(true);
                    }}
                >
                    {Platform.OS != "web" &&
                        <Icon as={Ionicons} name="search" size={30} style={{ ...theme.headerIcon }} />
                    }
                    {Platform.OS == "web" &&
                        <SearchOutlined style={{ ...theme.headerIcon }} />
                    }
                </Button>
            )}
            <Button
                transparent
                style={theme.headerIcon}
                onPress={() => {
                    dispatch(sendRefreshRequest(usecaseId));
                }}
            >
                {Platform.OS != "web" &&
                    <Icon as={Ionicons} name="refresh" size={30} style={{ ...theme.headerIcon }} />
                }
                {Platform.OS == "web" &&
                    <ReloadOutlined style={{ ...theme.headerIcon }} />
                }

            </Button>
            <Button
                style={[theme.headerIcon]}
                transparent
                onPress={() => {
                    if (clientActions[vs.tdl.tdlId] && "back" in clientActions[vs.tdl.tdlId]) {
                        clientActions[vs.tdl.tdlId].back.execution({ store, vs })
                    } else if ("back" in clientActions) {
                        clientActions.back.execution({ store, vs })
                    } else {
                        dispatch(requestBack(usecaseId));
                    }
                }}
            >
                {Platform.OS != "web" &&
                    <Icon as={Ionicons} name={isRTL ? "arrow-back" : "arrow-forward"} size={30} style={{ ...theme.headerIcon }} />
                }
                {Platform.OS == "web" &&
                    <>
                        {isRTL ? <ArrowLeftOutlined style={{ ...theme.headerIcon }} /> : <ArrowRightOutlined style={{ ...theme.headerIcon }} />}
                    </>
                }
            </Button>

            {clientActions[vs.tdl.tdlId] &&
                Object.entries(clientActions[vs.tdl.tdlId]).map((action) => {
                    if (action.position === "header")
                        return (
                            <Button
                                style={theme.headerIcon}
                                transparent
                                onPress={() => {
                                    action.execution({ store, vs });
                                }}
                            >
                                <Icon as={Ionicons} name={action.icon} style={{ ...theme.headerIcon }} />
                            </Button>
                        );

                    return <></>
                })}
        </>
    );
    console.log("showHeader", showHeader)
    return (
        <>
            <View style={{ display: "flex", flexDirection: "row", marginBottom: 20 }}>
                <View style={{ flex: 1, backgroundColor: "blue" }}>
                    <Button >
                        <RightOutlined />
                    </Button>
                </View>
                <View style={{ flex: 2, backgroundColor: "pink", display: "flex", flexDirection: "row" }}>
                    {/* <View  style={{ flex: 1}}>
                        <Button >14</Button>
                    </View>
                    <View style={{ flex: 1}}>
                        <Button >15</Button>
                    </View> */}
                </View>
                <View style={{ flex: 1, backgroundColor: "red" }}>
                    <Button >
                        <LeftOutlined />
                    </Button>
                </View>
            </View>
        </>
    );
};

TdlFooter.propTypes = {
    vs: PropTypes.objectOf(PropTypes.any).isRequired,
    dispatch: PropTypes.func.isRequired,
    favorite: PropTypes.arrayOf(PropTypes.any).isRequired,
    timeZoneOffset: PropTypes.number.isRequired,
    smallView: PropTypes.bool,
    isRTL: PropTypes.bool.isRequired,
    themeName: PropTypes.string.isRequired,
    clientActions: PropTypes.objectOf(PropTypes.any),
};

TdlFooter.defaultProps = {
    smallView: false,
    clientActions: [],
};

// const isEqualTdlHeader = (prevProp, nextProp) =>
//   Util.isEqual(extractPropsFromVs(prevProp), extractPropsFromVs(nextProp));

export default TdlFooter;
// React.memo(TdlHeader, isEqualTdlHeader);

==> elixir-react-native-components-1.2.2-6.tgz: package/components/tdl/tdlFooter.js <==
import React, { useState } from "react";
import PropTypes from "prop-types";
import { HStack, Icon, InputRightAddon, InputLeftAddon, theme } from "native-base";
import { Modal, Platform, ScrollView, StyleSheet, Text, View } from "react-native";
import { Button } from "@ant-design/react-native";
import { getTheme } from "../../styles/themes";
import store from '@muhammadz/elixir-react-stateful/redux';
import { Ionicons } from '@expo/vector-icons';
import { Feather } from '@expo/vector-icons';
import { MaterialIcons } from '@expo/vector-icons';


import {
    requestBack,
    sendSearchRequest,
    changeActiveTab,
    sendRefreshRequest,
    setIsDrawerOpen,
} from "@muhammadz/elixir-react-stateful/redux/actions";
import Group from "../group/index";
import * as Util from "../../helpers/util";
import { getTranslation } from "../../labels";
import HTMLValue from "../htmlValue";
import { ArrowLeftOutlined, ArrowRightOutlined, InfoCircleOutlined, LeftOutlined, MoreOutlined, ReloadOutlined, RightOutlined, SearchOutlined } from "@ant-design/icons";
const themeTdl = getTheme("default");
const styles = StyleSheet.create({
    container: {
        alignItems: themeTdl.tdlContainer.alignItems,
        backgroundColor: themeTdl.tdlContainer.backgroundColor,
        padding: themeTdl.tdlContainer.padding,
    },
    modal: {
        flex: themeTdl.tdlModal.flex,
        alignItems: themeTdl.tdlModal.alignItems,
        backgroundColor: themeTdl.tdlModal.backgroundColor,
        padding: themeTdl.tdlModal.padding,
    },
    text: {
        color: themeTdl.tdlText.color,
        marginTop: themeTdl.tdlText.marginTop,
    },
});

const extractPropsFromVs = ({ vs, favorite }, changeTabHandler = () => { }) => {
    const {
        usecaseId,
        callerUsecaseId,
        count,
        filterInfo,
        filterName,
        hasServerFilter,
        isLoading,
        maxPageNumber,
        maxRowsSize,
        rowsNumber,
        favoriteItemInfo,
        callersLabelsArray,
    } = vs;
    const { SGroups, sortKeys, filtersNames, type, pageHelpSummary, pageHelp } = vs.tdl;
    const sortKey = vs.getSortKey();
    const actions = vs.getHeaderActions();
    const breads = [];
    return {
        usecaseId,
        callerUsecaseId,
        count,
        filterInfo,
        filterName,
        filtersNames,
        hasServerFilter,
        isLoading,
        maxPageNumber,
        maxRowsSize,
        rowsNumber,
        SGroups,
        sortKeys,
        type,
        sortKey,
        actions,
        breads,
        firstLevelEntry: callersLabelsArray.length === 0,
        inFavorite: favorite.find((item) => item.newTdlId === vs.tdl.tdlId),
        favoriteItemInfo,
        pageHelpSummary,
        pageHelp,
    };
};

const createSearchCriteriaModal = (vs, dispatch, timeZoneOffset, smallView, setSearchModalVisible, theme, isRTL) => {

    return (
        vs.tdl.SGroups &&
        vs.tdl.SGroups.map((sGroup, index) => (
            <>
                <ScrollView
                    style={{
                        flexGrow: theme.tdlScrollView.flexGrow,
                        // backgroundColor:"pink"
                    }}
                >
                    <Group
                        key={`${sGroup.id}${sGroup.pk}`}
                        vs={vs}
                        isSearch
                        tdlPath={`SGroups.${index}`}
                        dispatch={dispatch}
                        getTranslation={getTranslation}
                        smallView={smallView}
                        isRTL={isRTL}
                        theme={theme}
                    />
                </ScrollView>
                <View>
                    <Button
                        style={{ width: "100%" }}
                        onPress={() => {
                            dispatch(sendSearchRequest(vs.usecaseId));
                            setSearchModalVisible(false);
                        }}
                    >
                        <Text>{getTranslation("search")}</Text>
                    </Button>
                </View>
            </>
        ))
    );
};

const TdlFooter = ({ vs, favorite, dispatch, timeZoneOffset,
    smallView, isRTL, themeName, clientActions, showHeader }) => {
    const {
        usecaseId,
        callerUsecaseId,
        count,
        filterInfo,
        filterName,
        filtersNames,
        hasServerFilter,
        isLoading,
        maxPageNumber,
        maxRowsSize,
        rowsNumber,
        SGroups,
        sortKeys,
        type,
        sortKey,
        actions,
        breads,
        inFavorite,
        favoriteItemInfo,
        pageHelpSummary,
        pageHelp,
        firstLevelEntry,
    } = extractPropsFromVs({ vs, favorite }, (targetUsecaseId) => {
        if (targetUsecaseId === "home") {
            dispatch(changeActiveTab("home"));
            return;
        }
        if (targetUsecaseId !== vs.usecaseId) {
            dispatch(requestBack(vs.usecaseId, targetUsecaseId));
        }
    });


    // console.log("isRTL in TDLHeader");
    // console.log(isRTL);
    const [helpModalVisible, setHelpModalVisible] = useState(false);
    const [searchModalVisible, setSearchModalVisible] = useState(false);
    const theme = getTheme(themeName);


    const backButton = (
        <Button
            transparent
            style={{ ...theme.headerIcon }}
            onPress={() => {
                // console.log("theme.headerIcon");
                //console.log(theme.headerIcon);
                setSearchModalVisible(false);
            }}
        >

            <Icon

                as={Ionicons}
                name={isRTL ? "arrow-back" : "arrow-forward"}
                style={{
                    ...theme.headerIcon,
                    padding: theme.tdlIcon.padding,
                    margin: theme.tdlIcon.margin,

                }}
            />
        </Button>
    );
    const optionsButton = (
        <Button
            transparent
            style={theme.headerIcon}
            onPress={() => {
                console.log("more clicked");
                dispatch(setIsDrawerOpen(true));
            }}
        >
            {Platform.OS != "web" &&
                <Feather name="more-vertical" size={25} style={{ ...theme.headerIcon }} />
            }
            {Platform.OS == "web" &&
                <MoreOutlined style={{ ...theme.headerIcon }} />
            }
        </Button>
    );

    const headerButtons = (
        <>
            {pageHelp != null && pageHelp !== "" && (
                <Button
                    transparent
                    style={theme.headerIcon}
                    onPress={() => {
                        setHelpModalVisible(true);
                    }}
                >
                    {Platform.OS != "web" &&
                        <Icon as={MaterialIcons} name="info" style={{ ...theme.headerIcon }} />
                    }
                    {Platform.OS == "web" &&
                        <InfoCircleOutlined style={{ ...theme.headerIcon }} />
                    }
                </Button>
            )}

            {vs.tdl.type === "SMS" && (
                <Button
                    transparent
                    style={theme.headerIcon}
                    onPress={() => {
                        setSearchModalVisible(true);
                    }}
                >
                    {Platform.OS != "web" &&
                        <Icon as={Ionicons} name="search" size={30} style={{ ...theme.headerIcon }} />
                    }
                    {Platform.OS == "web" &&
                        <SearchOutlined style={{ ...theme.headerIcon }} />
                    }
                </Button>
            )}
            <Button
                transparent
                style={theme.headerIcon}
                onPress={() => {
                    dispatch(sendRefreshRequest(usecaseId));
                }}
            >
                {Platform.OS != "web" &&
                    <Icon as={Ionicons} name="refresh" size={30} style={{ ...theme.headerIcon }} />
                }
                {Platform.OS == "web" &&
                    <ReloadOutlined style={{ ...theme.headerIcon }} />
                }

            </Button>
            <Button
                style={[theme.headerIcon]}
                transparent
                onPress={() => {
                    if (clientActions[vs.tdl.tdlId] && "back" in clientActions[vs.tdl.tdlId]) {
                        clientActions[vs.tdl.tdlId].back.execution({ store, vs })
                    } else if ("back" in clientActions) {
                        clientActions.back.execution({ store, vs })
                    } else {
                        dispatch(requestBack(usecaseId));
                    }
                }}
            >
                {Platform.OS != "web" &&
                    <Icon as={Ionicons} name={isRTL ? "arrow-back" : "arrow-forward"} size={30} style={{ ...theme.headerIcon }} />
                }
                {Platform.OS == "web" &&
                    <>
                        {isRTL ? <ArrowLeftOutlined style={{ ...theme.headerIcon }} /> : <ArrowRightOutlined style={{ ...theme.headerIcon }} />}
                    </>
                }
            </Button>

            {clientActions[vs.tdl.tdlId] &&
                Object.entries(clientActions[vs.tdl.tdlId]).map((action) => {
                    if (action.position === "header")
                        return (
                            <Button
                                style={theme.headerIcon}
                                transparent
                                onPress={() => {
                                    action.execution({ store, vs });
                                }}
                            >
                                <Icon as={Ionicons} name={action.icon} style={{ ...theme.headerIcon }} />
                            </Button>
                        );

                    return <></>
                })}
        </>
    );
    console.log("showHeader", showHeader)
    return (
        <>
            <View style={{ display: "flex", flexDirection: "row", marginBottom: 20 }}>
                <View style={{ flex: 1, backgroundColor: "blue" }}>
                    <Button >
                        <RightOutlined />
                    </Button>
                </View>
                <View style={{ flex: 2, backgroundColor: "pink", display: "flex", flexDirection: "row" }}>
                    {/* <View  style={{ flex: 1}}>
                        <Button >14</Button>
                    </View>
                    <View style={{ flex: 1}}>
                        <Button >15</Button>
                    </View> */}
                </View>
                <View style={{ flex: 1, backgroundColor: "red" }}>
                    <Button >
                        <LeftOutlined />
                    </Button>
                </View>
            </View>
        </>
    );
};

TdlFooter.propTypes = {
    vs: PropTypes.objectOf(PropTypes.any).isRequired,
    dispatch: PropTypes.func.isRequired,
    favorite: PropTypes.arrayOf(PropTypes.any).isRequired,
    timeZoneOffset: PropTypes.number.isRequired,
    smallView: PropTypes.bool,
    isRTL: PropTypes.bool.isRequired,
    themeName: PropTypes.string.isRequired,
    clientActions: PropTypes.objectOf(PropTypes.any),
};

TdlFooter.defaultProps = {
    smallView: false,
    clientActions: [],
};

// const isEqualTdlHeader = (prevProp, nextProp) =>
//   Util.isEqual(extractPropsFromVs(prevProp), extractPropsFromVs(nextProp));

export default TdlFooter;
// React.memo(TdlHeader, isEqualTdlHeader);
